from setuptools import setup

setup(name='sort_natural_keys',
      version='0.0.0',
      description='Sorts with natural keys an array of string.',
      url='https://gitlab.com/quotengo/util/sort-natural-keys.git',
      author='Jean-Sébastien Patenaude',
      author_email='js.patenaude.quotengo@gmail.com',
      license='MIT',
      packages=['sort_natural_keys'],
      zip_safe=False)